==> tine20-allinone_2020.08.8.tar.bz2: Crm/js/Crm-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0 - Crm\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "All leads"
: "All leads"

, "Default Lead List"
: "Default Lead List"

, "The default list for new leads"
: "The default list for new leads"

, "Get Notification Emails"
: "Get Notification Emails"

, "The level of actions you want to be notified about."
: "The level of actions you want to be notified about."

, "Send Notifications Emails for own actions"
: "Send Notifications Emails for own actions"

, "Get notifications emails for actions you did yourself"
: "Get notifications emails for actions you did yourself"

, "Send Notifications Emails to responsible"
: "Send Notifications Emails to responsible"

, "Get notifications emails for action to responsible"
: "Get notifications emails for action to responsible"

, "Send Notifications Emails to customer"
: "Send Notifications Emails to customer"

, "Get notifications emails for action to customer"
: "Get notifications emails for action to customer"

, "Send Notifications Emails to partner"
: "Send Notifications Emails to partner"

, "Get notifications emails for action to partner"
: "Get notifications emails for action to partner"

, "Default Favorite"
: "Default Favorite"

, "The default favorite which is loaded on crm startup"
: "The default favorite which is loaded on crm startup"

, "New Lead"
: "New Lead"

, "Tags"
: "Tags"

, "Lead name"
: "Lead name"

, "Responsible"
: "Responsible"

, "Partner"
: "Partner"

, "Customer"
: "Customer"

, "Leadstate"
: "Leadstate"

, "Leadtype"
: "Leadtype"

, "Leadsource"
: "Leadsource"

, "Probability"
: "Probability"

, "Turnover"
: "Turnover"

, "Estimated end"
: "Estimated end"

, "Probable Turnover"
: "Probable Turnover"

, "Resubmission Date"
: "Resubmission Date"

, "Import leads"
: "Import leads"

, "Contact"
: "Contact"

, "CRM Role"
: "CRM Role"

, "Tasks"
: "Tasks"

, "No Tasks to display"
: "No Tasks to display"

, "Summary"
: "Summary"

, "Add a task..."
: "Add a task..."

, "Due Date"
: "Due Date"

, "Priority"
: "Priority"

, "Percent"
: "Percent"

, "Status"
: "Status"

, "Organizer"
: "Organizer"

, "Add new {0}"
: "Add new {0}"

, "Unlink {0}"
: "Unlink {0}"

, "Unlink selected {0}"
: "Unlink selected {0}"

, "Edit {0}"
: "Edit {0}"

, "Edit selected {0}"
: "Edit selected {0}"

, "Please choose the Lead to add the contacts to"
: "Please choose the Lead to add the contacts to"

, "Please select the attenders' role"
: "Please select the attenders' role"

, "Lead, Leads"
: [
  "Lead"
 ,"Leads"

]
, "Select Lead"
: "Select Lead"

, "Role"
: "Role"

, "Select Role"
: "Select Role"

, "Adding {0} contacts to lead"
: "Adding {0} contacts to lead"

, "Phone"
: "Phone"

, "Mobile"
: "Mobile"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Mail"

, "Web"
: "Web"

, "Street"
: "Street"

, "Postalcode"
: "Postalcode"

, "City"
: "City"

, "Start"
: "Start"

, "Change type to Customer"
: "Change type to Customer"

, "Change type to Responsible"
: "Change type to Responsible"

, "Change type to Partner"
: "Change type to Partner"

, "Change contact type"
: "Change contact type"

, "Search for Contacts to add ..."
: "Search for Contacts to add ..."

, "Name"
: "Name"

, "Address"
: "Address"

, "Data"
: "Data"

, "Cellphone"
: "Cellphone"

, "End"
: "End"

, "You do not have the run right for the Tasks application or it is not activated."
: "You do not have the run right for the Tasks application or it is not activated."

, "Products"
: "Products"

, "You do not have the run right for the Sales application or it is not activated."
: "You do not have the run right for the Sales application or it is not activated."

, "Enter lead name"
: "Enter lead name"

, "Expected turnover"
: "Expected turnover"

, "Description"
: "Description"

, "Enter description"
: "Enter description"

, "lead list, lead lists"
: [
  "lead list"
 ,"lead lists"

]
, "lead lists"
: "lead lists"

, "Quick Search"
: "Quick Search"

, "Last Modified Time"
: "Last Modified Time"

, "Last Modified By"
: "Last Modified By"

, "Creation Time"
: "Creation Time"

, "Created By"
: "Created By"

, "X Lead"
: "X Lead"

, "Archived"
: "Archived"

, "Product"
: "Product"

, "Price"
: "Price"

, "Quantity"
: "Quantity"

, "Search for Products to add ..."
: "Search for Products to add ..."

, "All leads I have read grants for"
: "All leads I have read grants for"

, "Last modified by me"
: "Last modified by me"

, "All leads that I have last modified"
: "All leads that I have last modified"

, "My leads"
: "My leads"

, "All leads that I am responsible for"
: "All leads that I am responsible for"

, "Leads with overdue tasks"
: "Leads with overdue tasks"

, "Lead States Available"
: "Lead States Available"

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."

, "open"
: "open"

, "contacted"
: "contacted"

, "waiting for feedback"
: "waiting for feedback"

, "quote sent"
: "quote sent"

, "accepted"
: "accepted"

, "lost"
: "lost"

, "Lead Sources Available"
: "Lead Sources Available"

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."

, "Lead Types Available"
: "Lead Types Available"

, "Possible lead types."
: "Possible lead types."

, "Reseller"
: "Reseller"

, "Enabled Features"
: "Enabled Features"

, "Enabled Features in Crm Application."
: "Enabled Features in Crm Application."

, "Lead Import"
: "Lead Import"

, "Add new task on lead import"
: "Add new task on lead import"

, "Automatically creates a task for the responsible person if a new lead is imported."
: "Automatically creates a task for the responsible person if a new lead is imported."

, "Send notification email on lead import"
: "Send notification email on lead import"

, "Sends an email to all responsible persons for the imported leads."
: "Sends an email to all responsible persons for the imported leads."

, "Lead duplicate check fields"
: "Lead duplicate check fields"

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."

, "State"
: "State"

, "Source"
: "Source"

, "Scheduled end"
: "Scheduled end"

, "Folder"
: "Folder"

, "Updated by"
: "Updated by"

, "Updated Fields:"
: "Updated Fields:"

, "'%s' changed from '%s' to '%s'."
: "'%s' changed from '%s' to '%s'."

, "Lead %s has been changed"
: "Lead %s has been changed"

, "Lead %s has been deleted"
: "Lead %s has been deleted"

, "Lead %s has been created"
: "Lead %s has been created"

, "Task"
: "Task"

, "Lead Data"
: "Lead Data"

, "End Scheduled"
: "End Scheduled"

, "Contacts"
: "Contacts"

, "Telephone"
: "Telephone"

, "Email"
: "Email"

, "low"
: "low"

, "normal"
: "normal"

, "high"
: "high"

, "urgent"
: "urgent"

, "Lead CSV import"
: "Lead CSV import"

, "Import list (###CURRENTDATE###)"
: "Import list (###CURRENTDATE###)"

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"

, "Edit new lead"
: "Edit new lead"

, "The following leads have just been imported into lead list %s"
: "The following leads have just been imported into lead list %s"

, "%s new leads have been imported"
: "%s new leads have been imported"

, "manage shared lead folders"
: "manage shared lead folders"

, "Create new shared lead folders"
: "Create new shared lead folders"

, "manage shared leads favorites"
: "manage shared leads favorites"

, "Create or update shared leads favorites"
: "Create or update shared leads favorites"

, "Get Notification E-mails"
: "Get Notification E-mails"

, "Send Notifications e-mails for own actions"
: "Send Notifications e-mails for own actions"

, "Get notifications e-mails for actions you did yourself"
: "Get notifications e-mails for actions you did yourself"

, "Send Notifications e-mails to responsible"
: "Send Notifications e-mails to responsible"

, "Get notifications e-mails for action to responsible"
: "Get notifications e-mails for action to responsible"

, "Send Notifications e-mails to customer"
: "Send Notifications e-mails to customer"

, "Get notifications e-mails for action to customer"
: "Get notifications e-mails for action to customer"

, "Send Notifications e-mails to partner"
: "Send Notifications e-mails to partner"

, "Get notifications e-mails for action to partner"
: "Get notifications e-mails for action to partner"

, "Enabled Features in CRM Application."
: "Enabled Features in CRM Application."

, "Send notification e-mail on lead import"
: "Send notification e-mail on lead import"

, "Sends an e-mail to all responsible persons for the imported leads."
: "Sends an e-mail to all responsible persons for the imported leads."

, "All without me"
: "All without me"

, "All"
: "All"

, "Nobody"
: "Nobody"

, "send notification"
: "send notification"

, "controls sending notification of Leads"
: "controls sending notification of Leads"

, "Your are sure, that some changes can send a notification?"
: "Your are sure, that some changes can send a notification?"

, "Mute Notification"
: "Mute Notification"
, "Lead"
: "Lead"

, "lead list"
: "lead list"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Crm/js/Crm-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0 - Crm\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Customer"
: "Customer"

, "Partner"
: "Partner"

, "Phone"
: "Phone"

, "Mobile"
: "Mobile"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Mail"

, "Web"
: "Web"

, "Street"
: "Street"

, "Postalcode"
: "Postalcode"

, "City"
: "City"

, "Status"
: "Status"

, "Start"
: "Start"

, "Estimated end"
: "Estimated end"

, "Leadtype"
: "Leadtype"

, "Leadsource"
: "Leadsource"

, "Tags"
: "Tags"

, "Lead name"
: "Lead name"

, "Responsible"
: "Responsible"

, "Leadstate"
: "Leadstate"

, "Probability"
: "Probability"

, "Turnover"
: "Turnover"

, "End"
: "End"

, "Probable Turnover"
: "Probable Turnover"

, "Resubmission Date"
: "Resubmission Date"

, "Import leads"
: "Import leads"

, "Add new {0}"
: "Add new {0}"

, "Unlink {0}"
: "Unlink {0}"

, "Unlink selected {0}"
: "Unlink selected {0}"

, "Edit {0}"
: "Edit {0}"

, "Edit selected {0}"
: "Edit selected {0}"

, "New Lead"
: "New Lead"

, "Products"
: "Products"

, "Product"
: "Product"

, "Description"
: "Description"

, "Price"
: "Price"

, "Quantity"
: "Quantity"

, "Search for Products to add ..."
: "Search for Products to add ..."

, "1"
: "1"

, "Notifications are disabled"
: "Notifications are disabled"

, "Send Notification?"
: "Send Notification?"

, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""

, "Tasks"
: "Tasks"

, "You do not have the run right for the Tasks application or it is not activated."
: "You do not have the run right for the Tasks application or it is not activated."

, "You do not have the run right for the Sales application or it is not activated."
: "You do not have the run right for the Sales application or it is not activated."

, "Lead, Leads"
: [
  "Lead"
 ,"Leads"

]
, "Enter lead name"
: "Enter lead name"

, "Expected turnover"
: "Expected turnover"

, "Enter description"
: "Enter description"

, "lead list, lead lists"
: [
  "lead list"
 ,"lead lists"

]
, "lead lists"
: "lead lists"

, "Quick Search"
: "Quick Search"

, "Last Modified Time"
: "Last Modified Time"

, "Last Modified By"
: "Last Modified By"

, "Creation Time"
: "Creation Time"

, "Created By"
: "Created By"

, "X Lead"
: "X Lead"

, "read-only"
: "read-only"

, "Archived"
: "Archived"

, "Contact"
: "Contact"

, "CRM Role"
: "CRM Role"

, "Change type to Customer"
: "Change type to Customer"

, "Change type to Responsible"
: "Change type to Responsible"

, "Change type to Partner"
: "Change type to Partner"

, "Change contact type"
: "Change contact type"

, "Search for Contacts to add ..."
: "Search for Contacts to add ..."

, "Name"
: "Name"

, "Address"
: "Address"

, "Data"
: "Data"

, "Cellphone"
: "Cellphone"

, "Role"
: "Role"

, "Please choose the Lead to add the contacts to"
: "Please choose the Lead to add the contacts to"

, "Please select the attenders' role"
: "Please select the attenders' role"

, "Select Lead"
: "Select Lead"

, "Select Role"
: "Select Role"

, "Adding {0} contacts to lead"
: "Adding {0} contacts to lead"

, "No Tasks to display"
: "No Tasks to display"

, "Summary"
: "Summary"

, "Add a task..."
: "Add a task..."

, "Due Date"
: "Due Date"

, "Priority"
: "Priority"

, "Percent"
: "Percent"

, "Organizer"
: "Organizer"

, "All leads"
: "All leads"

, "Default Lead List"
: "Default Lead List"

, "The default list for new leads"
: "The default list for new leads"

, "Get Notification E-mails"
: "Get Notification E-mails"

, "The level of actions you want to be notified about."
: "The level of actions you want to be notified about."

, "Send Notifications e-mails for own actions"
: "Send Notifications e-mails for own actions"

, "Get notifications e-mails for actions you did yourself"
: "Get notifications e-mails for actions you did yourself"

, "Default Favorite"
: "Default Favorite"

, "The default favorite which is loaded on crm startup"
: "The default favorite which is loaded on crm startup"

, "controls sending notification of Leads"
: "controls sending notification of Leads"

, "send notification)description"
: "send notification)description"

, "send notification to all access container"
: "send notification to all access container"

, "send notification to responsible"
: "send notification to responsible"

, "send notification to responsible)description"
: "send notification to responsible)description"

, "send notification to customer"
: "send notification to customer"

, "send notification to partner"
: "send notification to partner"

, "Lead States Available"
: "Lead States Available"

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."

, "open"
: "open"

, "contacted"
: "contacted"

, "waiting for feedback"
: "waiting for feedback"

, "quote sent"
: "quote sent"

, "accepted"
: "accepted"

, "lost"
: "lost"

, "Lead Sources Available"
: "Lead Sources Available"

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."

, "Lead Types Available"
: "Lead Types Available"

, "Possible lead types."
: "Possible lead types."

, "Reseller"
: "Reseller"

, "Enabled Features"
: "Enabled Features"

, "Enabled Features in CRM Application."
: "Enabled Features in CRM Application."

, "Lead Import"
: "Lead Import"

, "Lead Notification Confirmation"
: "Lead Notification Confirmation"

, "Add new task on lead import"
: "Add new task on lead import"

, "Automatically creates a task for the responsible person if a new lead is imported."
: "Automatically creates a task for the responsible person if a new lead is imported."

, "Send notification e-mail on lead import"
: "Send notification e-mail on lead import"

, "Sends an e-mail to all responsible persons for the imported leads."
: "Sends an e-mail to all responsible persons for the imported leads."

, "Lead duplicate check fields"
: "Lead duplicate check fields"

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."

, "Lead Data"
: "Lead Data"

, "End Scheduled"
: "End Scheduled"

, "Contacts"
: "Contacts"

, "Telephone"
: "Telephone"

, "Email"
: "Email"

, "low"
: "low"

, "normal"
: "normal"

, "high"
: "high"

, "urgent"
: "urgent"

, "CSV all data"
: "CSV all data"

, "Lead CSV import"
: "Lead CSV import"

, "Import list (###CURRENTDATE###)"
: "Import list (###CURRENTDATE###)"

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"

, "Edit new lead"
: "Edit new lead"

, "The following leads have just been imported into lead list %s"
: "The following leads have just been imported into lead list %s"

, "%s new leads have been imported"
: "%s new leads have been imported"

, "GENDER_Lead"
: "GENDER_Lead"

, "Show Closed"
: "Show Closed"

, "Task"
: "Task"

, "State"
: "State"

, "Source"
: "Source"

, "Scheduled end"
: "Scheduled end"

, "Folder"
: "Folder"

, "Updated by"
: "Updated by"

, "Updated Fields:"
: "Updated Fields:"

, "'%s' changed from '%s' to '%s'."
: "'%s' changed from '%s' to '%s'."

, "Lead %s has been changed"
: "Lead %s has been changed"

, "Lead %s has been deleted"
: "Lead %s has been deleted"

, "Lead %s has been created"
: "Lead %s has been created"

, "This Lead state is set to read-only therefore updating this Lead is not possible."
: "This Lead state is set to read-only therefore updating this Lead is not possible."

, "All leads I have read grants for"
: "All leads I have read grants for"

, "Last modified by me"
: "Last modified by me"

, "All leads that I have last modified"
: "All leads that I have last modified"

, "My leads"
: "My leads"

, "All leads that I am responsible for"
: "All leads that I am responsible for"

, "Leads with overdue tasks"
: "Leads with overdue tasks"

, "manage shared lead folders"
: "manage shared lead folders"

, "Create new shared lead folders"
: "Create new shared lead folders"

, "manage shared leads favorites"
: "manage shared leads favorites"

, "Create or update shared leads favorites"
: "Create or update shared leads favorites"

, "Lead"
: "Lead"

, "lead list"
: "lead list"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
